/////////////////////////////////////////////////////////////////////////////
// PluginTemplate.cpp defines plugin loading/unloading and execution

#include "stdafx.h"
#include <afxdllx.h>

/////////////////////////////////////////////////////////////////////////////
// QCKPLUGIN API
// API and plugin header files

#include "qckplugin.h"
#include "PluginDlg.h"

/////////////////////////////////////////////////////////////////////////////

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// QCKPLUGIN API
// The one and only plugin dialog object

static CPluginDlg* TheDlg = 0;

/////////////////////////////////////////////////////////////////////////////
// QCKPLUGIN API
// Define InitQckPlugin to be called when the plugin is loaded/initialized

int InitQckPlugin(const char* path, void* handle, void* manager)
{

// Construct the dialog

  TheDlg = new CPluginDlg();
  if(!TheDlg)
	  return 1;

// Initialize the plugin

  IQckSrvcMgr* mgr = (IQckSrvcMgr*)manager;
  TheDlg->m_Handle = handle;

// Register this plugin with the menu service

  IQckMenuSrvc* menu = mgr->RegisterForMenuItemService();
  if(menu) {

// Add the menu item for the plugin

	  menu->CreateMenuItem(handle, PluginName);
  }
  TheDlg->m_Manager = mgr;

  return 0;
}

/////////////////////////////////////////////////////////////////////////////
// QCKPLUGIN API
// Define ExecuteQckPlugin to be called when a plugin menu item is selected

void ExecuteQckPlugin(int argc, void* argv)
{
  if(TheDlg) {

// Create the dialog

    if (!::IsWindow(TheDlg->GetSafeHwnd())) {
      TheDlg->Create(IDD_DIALOG, AfxGetMainWnd());
    }

// Show the dialog

    TheDlg->ShowWindow(SW_SHOW);
  }
}

/////////////////////////////////////////////////////////////////////////////
// QCKPLUGIN API
// Define CloseQckPlugin to be called when the plugin is unloaded/closeed

void CloseQckPlugin()
{
  if(TheDlg) {

// Delete the dialog

	  delete TheDlg;
	  TheDlg = NULL;
  }
}

/////////////////////////////////////////////////////////////////////////////
// AppWizard generated content

static AFX_EXTENSION_MODULE PluginTemplateDLL = { NULL, NULL };

extern "C" int APIENTRY
DllMain(HINSTANCE hInstance, DWORD dwReason, LPVOID lpReserved)
{
	// Remove this if you use lpReserved
	UNREFERENCED_PARAMETER(lpReserved);

	if (dwReason == DLL_PROCESS_ATTACH)
	{
		TRACE0("PLUGINTEMPLATE.DLL Initializing!\n");
		
		// Extension DLL one-time initialization
		if (!AfxInitExtensionModule(PluginTemplateDLL, hInstance))
			return 0;

		new CDynLinkLibrary(PluginTemplateDLL);
	}
	else if (dwReason == DLL_PROCESS_DETACH)
	{
		TRACE0("PLUGINTEMPLATE.DLL Terminating!\n");
		// Terminate the library before destructors are called
		AfxTermExtensionModule(PluginTemplateDLL);
	}
	return 1;   // ok
}

/////////////////////////////////////////////////////////////////////////////